import { Sequelize, DataTypes, Model, Optional } from "sequelize";
import { BoatTypeInput } from "./BoatType";

interface BoatAttributes {
  id: string;
  name: string;
  boattype: string;
  status: boolean;
  tags: Array<string>;
}

export interface BoatAttributesInput extends Optional<BoatAttributes, "id"> { }

class Boat extends Model<BoatAttributes, BoatTypeInput> implements BoatAttributes {
  declare id: string;
  declare name: string;
  declare boattype: string;
  declare status: boolean;
  declare tags: Array<string>;

  declare readonly createdAt: Date;
  declare readonly updatedAt: Date;
}

export const initBoat = async (sequelizeConnection: Sequelize) => {
  Boat.init(
  {
    id: {
      type: DataTypes.UUID,
      defaultValue: DataTypes.UUIDV4,
      primaryKey: true,
      allowNull: false,
    },
    name: {
      type: new DataTypes.STRING(),
      allowNull: false,
    },
    boattype: {
      type: DataTypes.UUID,
      allowNull: false,
      references: {
        model: "boattype",
        key: "id",
      }
    },
    status: {
      type: DataTypes.BOOLEAN,
      allowNull: false,
    },
    tags: {
      type: new DataTypes.ARRAY(DataTypes.STRING),
    }
  },
  {
    tableName: "boat",
    sequelize: sequelizeConnection,
  }
);
};

export default Boat;
